@@ -1,21 +1,8 @@
-/* This file is part of the KDE libraries
-    Copyright (c) 2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2009 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 2 of the License or ( at
-    your option ) version 3 or, at the discretion of KDE e.V. ( which shall
-    act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "testxmlguiwindow.h"
@@ -92,7 +79,8 @@ static void copy_dir(const QString &from, const QDir &to)
     QDir src = QDir(from);
     QDir dest = QDir(to.filePath(src.dirName()));
     to.mkpath(src.dirName());
-    foreach (const QFileInfo &fileInfo, src.entryInfoList(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot)) {
+    const auto fileInfos = src.entryInfoList(QDir::Dirs | QDir::Files | QDir::NoDotAndDotDot);
+    for (const QFileInfo &fileInfo : fileInfos) {
         if (fileInfo.isDir()) {
             copy_dir(fileInfo.filePath(), dest);
         } else {
@@ -652,7 +640,8 @@ void tst_KToolBar::testKAuthorizedDisableToggleAction()
     TestXmlGuiWindow kmw(m_xml, "tst_ktoolbar.rc");
     kmw.createGUI();
 
-    foreach (KToolBar *toolbar, kmw.toolBars()) {
+    const auto toolbars = kmw.toolBars();
+    for (KToolBar *toolbar: toolbars) {
         QVERIFY(!toolbar->toggleViewAction()->isEnabled());
     }
 }
