@@ -34,7 +34,6 @@
 #include <QGuiApplication>
 #include <QMap>
 #include <QList>
-#include <QAction>
 #include <QMetaMethod>
 
 #include <stdio.h>
@@ -639,6 +638,9 @@ bool KActionCollectionPrivate::writeKXMLGUIConfigFile()
 
     // Write back to XML file
     KXMLGUIFactory::saveConfigFile(doc, kxmlguiClient->localXMLFile(), q->componentName());
+    // and since we just changed the xml file clear the dom we have in memory
+    // it'll be rebuilt if needed
+    const_cast<KXMLGUIClient*>(kxmlguiClient)->setXMLGUIBuildDocument({});
     return true;
 }
 
@@ -752,7 +754,7 @@ void KActionCollectionPrivate::_k_actionDestroyed(QObject *obj)
 
     //HACK the object we emit is partly destroyed
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-    emit q->removed(action); //deprecated. remove in KDE5
+    emit q->removed(action);
 #endif
     emit q->changed();
 }
