@@ -1,26 +1,15 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1999 Reginald Stadlbauer <reggie@kde.org>
-              (C) 1999 Simon Hausmann <hausmann@kde.org>
-              (C) 2000 Nicolas Hadacek <haadcek@kde.org>
-              (C) 2000 Kurt Granroth <granroth@kde.org>
-              (C) 2000 Michael Koch <koch@kde.org>
-              (C) 2001 Holger Freyther <freyther@kde.org>
-              (C) 2002 Ellis Whitehead <ellis@kde.org>
-              (C) 2005-2006 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1999 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Nicolas Hadacek <haadcek@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
+    SPDX-FileCopyrightText: 2000 Michael Koch <koch@kde.org>
+    SPDX-FileCopyrightText: 2001 Holger Freyther <freyther@kde.org>
+    SPDX-FileCopyrightText: 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KACTIONCOLLECTION_H
@@ -39,6 +28,8 @@ class QActionGroup;
 class QString;
 
 /**
+ * @class KActionCollection kactioncollection.h KActionCollection
+ *
  * \short A container for a set of QAction objects.
  *
  * KActionCollection manages a set of QAction objects.  It
@@ -72,7 +63,7 @@ public:
     /**
      * Destructor.
      */
-    virtual ~KActionCollection();
+    ~KActionCollection() override;
 
     /**
      * Access the list of all action collections in existence for this app
@@ -85,8 +76,8 @@ public:
     void clear();
 
     /**
-     * Associate all actions in this collection to the given \a widget.
-     * Unlike addAssociatedWidget, this method only adds all current actions
+     * Associate all actions in this collection to the given @p widget.
+     * Unlike addAssociatedWidget(), this method only adds all current actions
      * in the collection to the given widget. Any action added after this call
      * will not be added to the given widget automatically.
      * So this is just a shortcut for a foreach loop and a widget->addAction call.
@@ -94,7 +85,7 @@ public:
     void associateWidget(QWidget *widget) const;
 
     /**
-     * Associate all actions in this collection to the given \a widget, including any actions
+     * Associate all actions in this collection to the given @p widget, including any actions
      * added after this association is made.
      *
      * This does not change the action's shortcut context, so if you need to have the actions only
@@ -104,7 +95,7 @@ public:
     void addAssociatedWidget(QWidget *widget);
 
     /**
-     * Remove an association between all actions in this collection and the given \a widget, i.e.
+     * Remove an association between all actions in this collection and the given @p widget, i.e.
      * remove those actions from the widget, and stop associating newly added actions as well.
      */
     void removeAssociatedWidget(QWidget *widget);
@@ -125,19 +116,19 @@ public:
     QString configGroup() const;
 
     /**
-     * Returns whether this action collection's configuration should be global to KDE ( \e true ),
-     * or specific to the application ( \e false ).
+     * Returns whether this action collection's configuration should be global to KDE ( @c true ),
+     * or specific to the application ( @c false ).
      */
     bool configIsGlobal() const;
 
     /**
-     * Sets \a group as the KConfig group with which settings will be loaded and saved.
+     * Sets @p group as the KConfig group with which settings will be loaded and saved.
      */
     void setConfigGroup(const QString &group);
 
     /**
-     * Set whether this action collection's configuration should be global to KDE ( \e true ),
-     * or specific to the application ( \e false ).
+     * Set whether this action collection's configuration should be global to KDE ( @c true ),
+     * or specific to the application ( @c false ).
      */
     void setConfigGlobal(bool global);
 
@@ -170,13 +161,13 @@ public:
     void exportGlobalShortcuts(KConfigGroup *config, bool writeDefaults = false) const;
 
     /**
-      * Write the current configurable key associations to @a config. What the
-      * function does if @a config is zero depends. If this action collection
-      * belongs to a KXMLGuiClient the setting are saved to the kxmlgui
+      * Write the current configurable key associations to @p config. What the
+      * function does if @p config is zero depends. If this action collection
+      * belongs to a KXMLGUIClient the setting are saved to the kxmlgui
       * definition file. If not the settings are written to the applications
       * config file.
       *
-      * \note oneAction() and writeDefaults() have no meaning for the kxmlgui
+      * \note @p oneAction and @p writeDefaults have no meaning for the kxmlgui
       * configuration file.
       *
       * \param config Config object to save to, or null (see above)
@@ -199,14 +190,14 @@ public:
     bool isEmpty() const;
 
     /**
-     * Return the QAction* at position "index" in the action collection.
+     * Return the QAction* at position @p index in the action collection.
      *
      * This is equivalent to actions().value(index);
      */
     QAction *action(int index) const;
 
     /**
-     * Get the action with the given \a name from the action collection.
+     * Get the action with the given \p name from the action collection.
      *
      * @param name Name of the QAction
      * @return A pointer to the QAction in the collection which matches the parameters or
@@ -233,14 +224,14 @@ public:
     const QList<QActionGroup *> actionGroups() const;
 
     /**
-     * Set the \a componentName associated with this action collection.
+     * Set the @p componentName associated with this action collection.
      *
      * \warning Don't call this method on a KActionCollection that contains
      * actions. This is not supported.
      *
      * \param componentData the name which is to be associated with this action collection,
      * or QString() to indicate the app name. This is used to load/save settings into XML files.
-     * KXmlGuiClient::setComponentName takes care of calling this.
+     * KXMLGUIClient::setComponentName takes care of calling this.
      */
     void setComponentName(const QString &componentName);
 
@@ -250,7 +241,7 @@ public:
     /**
      * Set the component display name associated with this action collection.
      * (e.g. for the toolbar editor)
-     * KXmlGuiClient::setComponentName takes care of calling this.
+     * KXMLGUIClient::setComponentName takes care of calling this.
      */
     void setComponentDisplayName(const QString &displayName);
 
@@ -264,44 +255,59 @@ public:
 
 Q_SIGNALS:
     /**
-     * Indicates that \a action was inserted into this action collection.
+     * Indicates that @p action was inserted into this action collection.
      */
     void inserted(QAction *action);
 
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
-     * Indicates that \a action was removed from this action collection.
-     * @deprecated
+     * Indicates that @p action was removed from this action collection.
+     * @deprecated Since 5.0, use changed() (added in 5.66) instead.
      */
+    KXMLGUI_DEPRECATED_VERSION(5, 0, "removed() is sometimes emitted with partially destroyed objects; use changed() instead (added in 5.66)")
     QT_MOC_COMPAT void removed(QAction *action);
+#endif
 
     /**
-     * Indicates that \a action was highlighted (hovered over).
-     * @deprecated Replaced by actionHovered(QAction* action);
+     * Emitted when an action has been inserted into, or removed from, this action collection.
+     * @since 5.66
      */
+    void changed();
+
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
+    /**
+     * Indicates that @p action was highlighted (hovered over).
+     * @deprecated Since 5.0. Replaced by actionHovered(QAction* action);
+     */
+    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use KActionCollection::actionHovered(QAction* action)")
     QT_MOC_COMPAT void actionHighlighted(QAction *action);
+#endif
 
     /**
-     * Indicates that \a action was hovered.
+     * Indicates that @p action was hovered.
      */
     void actionHovered(QAction *action);
 
     /**
-     * Indicates that \a action was triggered
+     * Indicates that @p action was triggered
      */
     void actionTriggered(QAction *action);
 
 protected:
     /// Overridden to perform connections when someone wants to know whether an action was highlighted or triggered
-    void connectNotify(const QMetaMethod &signal) Q_DECL_OVERRIDE;
+    void connectNotify(const QMetaMethod &signal) override;
 
 protected Q_SLOTS:
     virtual void slotActionTriggered();
 
+#if KXMLGUI_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @internal
-     * @deprecated Replaced by slotActionHovered();
+     * @deprecated Since 5.0. Replaced by slotActionHovered();
      */
+    KXMLGUI_DEPRECATED_VERSION(5, 0, "Use KActionCollection::slotActionHovered()")
     QT_MOC_COMPAT virtual void slotActionHighlighted();
+#endif
 
 private Q_SLOTS:
     void slotActionHovered();
@@ -320,6 +326,9 @@ public:
      * If KAuthorized::authorizeAction() reports that the action is not
      * authorized, it will be disabled and hidden.
      *
+     * The ownership of the action object is not transferred.
+     * If the action is destroyed it will be removed automatically from the KActionCollection.
+     *
      * @param name The name by which the action be retrieved again from the collection.
      * @param action The action to add.
      * @return the same as the action given as parameter. This is just for convenience
@@ -333,7 +342,10 @@ public:
      *
      * The objectName of the actions is used as their internal name in the collection.
      *
-     * Uses addAction(QString, QAction*).
+     * The ownership of the action objects is not transferred.
+     * If the action is destroyed it will be removed automatically from the KActionCollection.
+     *
+     * Uses addAction(const QString&, QAction*).
      *
      * @param actions the list of the actions to add.
      *
@@ -350,6 +362,9 @@ public:
 
     /**
      * Removes an action from the collection.
+     *
+     * The ownership of the action object is not changed.
+     *
      * @param action the action to remove.
      */
     QAction *takeAction(QAction *action);
@@ -359,12 +374,14 @@ public:
      * action's triggered(bool) signal to the specified receiver/member. The
      * newly created action is also returned.
      *
-     * Note: Using KStandardAction::OpenRecent will cause a different signal than
+     * @note Using KStandardAction::OpenRecent will cause a different signal than
      * triggered(bool) to be used, see KStandardAction for more information.
      *
      * The action can be retrieved later from the collection by its standard name as per
      * KStandardAction::stdName.
      *
+     * The KActionCollection takes ownership of the action object.
+     *
      * @param actionType The standard action type of the action to create.
      * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
@@ -379,11 +396,13 @@ public:
      * and connects the action's triggered(bool) signal to the specified
      * receiver/member. The newly created action is also returned.
      *
-     * Note: Using KStandardAction::OpenRecent will cause a different signal than
+     * @note Using KStandardAction::OpenRecent will cause a different signal than
      * triggered(bool) to be used, see KStandardAction for more information.
      *
      * The action can be retrieved later from the collection by the specified name.
      *
+     * The KActionCollection takes ownership of the action object.
+     *
      * @param actionType The standard action type of the action to create.
      * @param name The name by which the action be retrieved again from the collection.
      * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
@@ -410,6 +429,8 @@ public:
      * Inserting an action under a name that is already used for another action will replace
      * the other action in the collection.
      *
+     * The KActionCollection takes ownership of the action object.
+     *
      * @param name The name by which the action be retrieved again from the collection.
      * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
@@ -428,6 +449,8 @@ public:
      * NOTE: KDE prior to 4.2 connected the triggered() signal instead of the triggered(bool)
      * signal.
      *
+     * The KActionCollection takes ownership of the action object.
+     *
      * @param name The internal name of the action (e.g. "file-open").
      * @param receiver The QObject to connect the triggered(bool) signal to.  Leave nullptr if no
      *                 connection is desired.
@@ -460,9 +483,14 @@ public:
      * @see add(const QString &, const QObject *, const char *)
      * @since 5.28
      */
+    #ifdef K_DOXYGEN
+    template<class ActionType>
+    inline ActionType *add(const QString &name, const Receiver *receiver, Func slot)
+    #else
     template<class ActionType, class Receiver, class Func>
     inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, ActionType>::type *add(
         const QString &name, const Receiver *receiver, Func slot)
+    #endif
     {
         ActionType *a = new ActionType(this);
         connect(a, &QAction::triggered, receiver, slot);
@@ -482,9 +510,13 @@ public:
      * @see addAction(const QString &, const QObject *, const char *)
      * @since 5.28
      */
+    #ifdef K_DOXYGEN
+    inline QAction *addAction(const QString &name, const Receiver *receiver, Func slot)
+    #else
     template<class Receiver, class Func>
     inline typename std::enable_if<!std::is_convertible<Func, const char*>::value, QAction>::type *addAction(
         const QString &name, const Receiver *receiver, Func slot)
+    #endif
     {
         return add<QAction>(name, receiver, slot);
     }
