@@ -1,23 +1,9 @@
 /*
- * This file is part of the KDE Libraries
- * Copyright (C) 1999-2000 Espen Sand (espen@kde.org)
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE Libraries
+    SPDX-FileCopyrightText: 1999-2000 Espen Sand <espen@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 // I (espen) prefer that header files are included alphabetically
 
@@ -53,21 +39,8 @@ class KHelpMenuPrivate
 {
 public:
     KHelpMenuPrivate()
-        : mSwitchApplicationLanguage(nullptr),
-          mActionsCreated(false),
-          mSwitchApplicationLanguageAction(nullptr),
-          mAboutData(KAboutData::applicationData())
+        : mAboutData(KAboutData::applicationData())
     {
-        mMenu = nullptr;
-        mAboutApp = nullptr;
-        mAboutKDE = nullptr;
-        mBugReport = nullptr;
-        mDonateAction = nullptr;
-        mHandBookAction = nullptr;
-        mWhatsThisAction = nullptr;
-        mReportBugAction = nullptr;
-        mAboutAppAction = nullptr;
-        mAboutKDEAction = nullptr;
     }
     ~KHelpMenuPrivate()
     {
@@ -80,22 +53,26 @@ public:
 
     void createActions(KHelpMenu *q);
 
-    QMenu *mMenu;
-    QDialog *mAboutApp;
-    KAboutKdeDialog *mAboutKDE;
-    KBugReport *mBugReport;
-    QAction *mDonateAction;
-    KSwitchLanguageDialog *mSwitchApplicationLanguage;
+    QMenu *mMenu = nullptr;
+    QDialog *mAboutApp = nullptr;
+    KAboutKdeDialog *mAboutKDE = nullptr;
+    KBugReport *mBugReport = nullptr;
+    QAction *mDonateAction = nullptr;
+    KSwitchLanguageDialog *mSwitchApplicationLanguage = nullptr;
 
 // TODO evaluate if we use static_cast<QWidget*>(parent()) instead of mParent to win that bit of memory
-    QWidget *mParent;
+    QWidget *mParent = nullptr;
     QString mAboutAppText;
 
-    bool mShowWhatsThis;
-    bool mActionsCreated;
+    bool mShowWhatsThis = false;
+    bool mActionsCreated = false;
 
-    QAction *mHandBookAction, *mWhatsThisAction;
-    QAction *mReportBugAction, *mSwitchApplicationLanguageAction, *mAboutAppAction, *mAboutKDEAction;
+    QAction *mHandBookAction = nullptr;
+    QAction *mWhatsThisAction = nullptr;
+    QAction *mReportBugAction = nullptr;
+    QAction *mSwitchApplicationLanguageAction = nullptr;
+    QAction *mAboutAppAction = nullptr;
+    QAction *mAboutKDEAction = nullptr;
 
     KAboutData mAboutData;
 };
@@ -149,7 +126,7 @@ void KHelpMenuPrivate::createActions(KHelpMenu *q)
     }
 
     if (KAuthorized::authorizeAction(QStringLiteral("switch_application_language"))) {
-        mSwitchApplicationLanguageAction = KStandardAction::create(KStandardAction::SwitchApplicationLanguage, q, SLOT(switchApplicationLanguage()), q);
+        mSwitchApplicationLanguageAction = KStandardAction::switchApplicationLanguage(q, SLOT(switchApplicationLanguage()), q);
     }
 
     if (KAuthorized::authorizeAction(QStringLiteral("help_about_app"))) {
