@@ -1,27 +1,15 @@
-/* This file is part of the KDE libraries
-    Copyright
-    (C) 2000 Reginald Stadlbauer (reggie@kde.org)
-    (C) 1997 Stephan Kulow (coolo@kde.org)
-    (C) 1997-2000 Sven Radej (radej@kde.org)
-    (C) 1997-2000 Matthias Ettrich (ettrich@kde.org)
-    (C) 1999 Chris Schlaeger (cs@kde.org)
-    (C) 2002 Joseph Wenninger (jowenn@kde.org)
-    (C) 2005-2006 Hamish Rodda (rodda@kde.org)
-    (C) 2000-2008 David Faure (faure@kde.org)
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2000 Reginald Stadlbauer <reggie@kde.org>
+    SPDX-FileCopyrightText: 1997 Stephan Kulow <coolo@kde.org>
+    SPDX-FileCopyrightText: 1997-2000 Sven Radej <radej@kde.org>
+    SPDX-FileCopyrightText: 1997-2000 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 1999 Chris Schlaeger <cs@kde.org>
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2000-2008 David Faure <faure@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kmainwindow.h"
@@ -55,7 +43,6 @@
 #include <kconfig.h>
 #include <ksharedconfig.h>
 #include <klocalizedstring.h>
-#include <kwindowsystem.h>
 #include <kconfiggroup.h>
 #include <kwindowconfig.h>
 #include <kconfiggui.h>
@@ -91,7 +78,7 @@ public:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
 private:
-    KMainWindow *m_win;
+    KMainWindow *const m_win;
 };
 
 DockResizeListener::DockResizeListener(KMainWindow *win) :
@@ -109,6 +96,7 @@ bool DockResizeListener::eventFilter(QObject *watched, QEvent *event)
     switch (event->type()) {
     case QEvent::Resize:
     case QEvent::Move:
+    case QEvent::Show:
     case QEvent::Hide:
         m_win->k_ptr->setSettingsDirty(KMainWindowPrivate::CompressCalls);
         break;
@@ -239,6 +227,21 @@ void KMainWindowPrivate::init(KMainWindow *_q)
 
     sMemberList()->append(q);
 
+    // Set the icon theme fallback to breeze (if not already set)
+    // Most of our apps use "lots" of icons that most of the times
+    // are only available with breeze, we still honour the user icon
+    // theme but if the icon is not found there, we go to breeze
+    // since it's almost sure it'll be there.
+    // This should be done as soon as possible (preferably via
+    // Q_COREAPP_STARTUP_FUNCTION), but as for now it cannot be done too soon
+    // as at that point QPlatformTheme is not instantiated yet and breaks the
+    // internal status of QIconLoader (see QTBUG-74252).
+    // See also discussion at https://phabricator.kde.org/D22488
+    // TODO: remove this once we depend on Qt 5.15.1, where this is fixed
+    if (QIcon::fallbackThemeName().isEmpty()) {
+        QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    }
+
     // If application is translated, load translator information for use in
     // KAboutApplicationDialog or other getters. The context and messages below
     // both must be exactly as listed, and are forced to be loaded from the
@@ -263,6 +266,7 @@ void KMainWindowPrivate::init(KMainWindow *_q)
     letDirtySettings = true;
 
     sizeApplied = false;
+    suppressCloseEvent = false;
 }
 
 static bool endsWithHashNumber(const QString &s)
@@ -340,8 +344,10 @@ void KMainWindowPrivate::polish(KMainWindow *q)
         s = objname + s;
     }
     q->setObjectName(s);
-    q->winId(); // workaround for setWindowRole() crashing, and set also window role, just in case TT
-    q->setWindowRole(s);   // will keep insisting that object name suddenly should not be used for window role
+    if (!q->window() || q->window() == q) {
+         q->winId(); // workaround for setWindowRole() crashing, and set also window role, just in case TT
+         q->setWindowRole(s);   // will keep insisting that object name suddenly should not be used for window role
+    }
 
     dbusName = QLatin1Char('/') + QCoreApplication::applicationName() + QLatin1Char('/');
     dbusName += q->objectName().replace(QLatin1Char('/'), QLatin1Char('_'));
@@ -438,24 +444,20 @@ QMenu *KMainWindow::customHelpMenu(bool showWhatsThis)
 
 bool KMainWindow::canBeRestored(int number)
 {
-    if (!qApp->isSessionRestored()) {
-        return false;
-    }
     KConfig *config = KConfigGui::sessionConfig();
     if (!config) {
         return false;
     }
 
     KConfigGroup group(config, "Number");
+    // TODO KF6: we should use 0 as the default value, not 1
+    // See also https://bugs.kde.org/show_bug.cgi?id=427552
     const int n = group.readEntry("NumberOfWindows", 1);
     return number >= 1 && number <= n;
 }
 
 const QString KMainWindow::classNameOfToplevel(int number)
 {
-    if (!qApp->isSessionRestored()) {
-        return QString();
-    }
     KConfig *config = KConfigGui::sessionConfig();
     if (!config) {
         return QString();
@@ -519,6 +521,10 @@ void KMainWindow::appHelpActivated()
 void KMainWindow::closeEvent(QCloseEvent *e)
 {
     K_D(KMainWindow);
+    if (d->suppressCloseEvent) {
+        e->accept();
+        return;
+    }
 
     // Save settings if auto-save is enabled, and settings have changed
     if (d->settingsTimer && d->settingsTimer->isActive()) {
@@ -529,6 +535,12 @@ void KMainWindow::closeEvent(QCloseEvent *e)
         d->sizeTimer->stop();
         d->_k_slotSaveAutoSaveSize();
     }
+    // Delete the marker that says we don't want to restore the position of the
+    // next-opened instance; now that a window is closing, we do want to do this
+    if (d->autoSaveGroup.isValid()) {
+        d->autoSaveGroup.deleteEntry("RestorePositionForNextInstance");
+    }
+    d->_k_slotSaveAutoSavePosition();
 
     if (queryClose()) {
         // widgets will start destroying themselves at this point and we don't
@@ -539,6 +551,9 @@ void KMainWindow::closeEvent(QCloseEvent *e)
     } else {
         e->ignore();    //if the window should not be closed, don't close it
     }
+    // If saving session, we are processing a fake close event, and might get the real one later.
+    if (e->isAccepted() && qApp->isSavingSession())
+        d->suppressCloseEvent = true;
 }
 
 bool KMainWindow::queryClose()
@@ -583,6 +598,7 @@ void KMainWindow::saveMainWindowSettings(KConfigGroup &cg)
     // Called by session management - or if we want to save the window size anyway
     if (d->autoSaveWindowSize) {
         KWindowConfig::saveWindowSize(windowHandle(), cg);
+        KWindowConfig::saveWindowPosition(windowHandle(), cg);
     }
 
     // One day will need to save the version number, but for now, assume 0
@@ -672,7 +688,7 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
     const bool oldLetDirtySettings = d->letDirtySettings;
     d->letDirtySettings = false;
 
-    if (!d->sizeApplied) {
+    if (!d->sizeApplied && (!window() || window() == this)) {
         winId(); // ensure there's a window created
         KWindowConfig::restoreWindowSize(windowHandle(), cg);
         // NOTICE: QWindow::setGeometry() does NOT impact the backing QWidget geometry even if the platform
@@ -680,6 +696,21 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
         // TODO: remove once this was resolved in QWidget QPA
         resize(windowHandle()->size());
         d->sizeApplied = true;
+
+        // Let the user opt out of KDE apps remembering window sizes if they
+        // find it annoying or it doesn't work for them due to other bugs.
+        KSharedConfigPtr config = KSharedConfig::openConfig();
+        KConfigGroup group(config, "General");
+        if (group.readEntry("AllowKDEAppsToRememberWindowPositions", true)) {
+            if (cg.readEntry("RestorePositionForNextInstance", true)) {
+                KWindowConfig::restoreWindowPosition(windowHandle(), cg);
+                // Save the fact that we now don't want to restore position
+                // anymore; if we did, the next instance would completely cover
+                // the existing one
+                KConfigGroup cgWritable = cg; // because cg is const
+                cgWritable.writeEntry("RestorePositionForNextInstance", false);
+            }
+        }
     }
 
     QStatusBar *sb = internalStatusBar(this);
@@ -762,6 +793,10 @@ void KMainWindow::setAutoSaveSettings(const QString &groupName, bool saveWindowS
 void KMainWindow::setAutoSaveSettings(const KConfigGroup &group,
                                       bool saveWindowSize)
 {
+    // We re making a little assumption that if you want to save the window
+    // size, you probably also want to save the window position too
+    // This avoids having to re-implement a new version of
+    // KMainWindow::setAutoSaveSettings that handles these cases independently
     K_D(KMainWindow);
     d->autoSaveSettings = true;
     d->autoSaveGroup = group;
@@ -899,6 +934,13 @@ void KMainWindowPrivate::_k_slotSaveAutoSaveSize()
     }
 }
 
+void KMainWindowPrivate::_k_slotSaveAutoSavePosition()
+{
+    if (autoSaveGroup.isValid()) {
+        KWindowConfig::saveWindowPosition(q->windowHandle(), autoSaveGroup);
+    }
+}
+
 KToolBar *KMainWindow::toolBar(const QString &name)
 {
     QString childName = name;
@@ -919,7 +961,8 @@ QList<KToolBar *> KMainWindow::toolBars() const
 {
     QList<KToolBar *> ret;
 
-    foreach (QObject *child, children())
+    const auto theChildren = children();
+    for (QObject *child : theChildren)
         if (KToolBar *toolBar = qobject_cast<KToolBar *>(child)) {
             ret.append(toolBar);
         }
