@@ -1,25 +1,13 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 1997 Nicolas Hadacek <hadacek@kde.org>
-    Copyright (C) 2001,2001 Ellis Whitehead <ellis@kde.org>
-    Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
-    Copyright (C) 2007 Roberto Raggi <roberto@kdevelop.org>
-    Copyright (C) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
-    Copyright (C) 2008 Michael Jansen <kde@michael-jansen.biz>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1997 Nicolas Hadacek <hadacek@kde.org>
+    SPDX-FileCopyrightText: 2001, 2001 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007 Roberto Raggi <roberto@kdevelop.org>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2008 Michael Jansen <kde@michael-jansen.biz>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KSHORTCUTSDIALOG_H
@@ -32,6 +20,8 @@
 #include "kshortcutseditor.h"
 
 /**
+ * @class KShortcutsDialog kshortcutsdialog.h KShortcutsDialog
+ *
  * @short Dialog for configuration of KActionCollection and KGlobalAccel.
  *
  * The KShortcutsDialog class is used for configuring dictionaries of key/action
@@ -45,14 +35,13 @@
  * KShortcutsDialog::configure( actionCollection() );
  * \endcode
  *
- * @since 4.3
- * By default this dialog is modal. If you don't want that, setModal(false) and then the non-static
+ * By default this dialog is modal (since 4.3). If you don't want that, setModal(false) and then the non-static
  * configure() will show the dialog. If you want to do anything extra when the dialog is done,
  * connect to okClicked() and/or cancelClicked(). However, if your extra stuff depends on the
  * changed settings already being saved, connect to saved() instead to be safe; if you connect to
  * okClicked() your function might be called before the save happens.
  *
- * example:
+ * Example:
  * \code
  * KShortcutsDialog dlg;
  * dlg.addCollection(myActions);
@@ -61,7 +50,7 @@
  * dlg.configure();
  * \endcode
  *
- * \image html kshortcutsdialog.png "KDE Shortcuts Dialog"
+ * \image html kshortcutsdialog.png "KShortcutsDialog"
  *
  * @author Nicolas Hadacek <hadacek@via.ecp.fr>
  * @author Hamish Rodda <rodda@kde.org> (KDE 4 porting)
@@ -79,12 +68,12 @@ public:
      */
     explicit KShortcutsDialog(KShortcutsEditor::ActionTypes types = KShortcutsEditor::AllActions,
                               KShortcutsEditor::LetterShortcuts allowLetterShortcuts = KShortcutsEditor::LetterShortcutsAllowed,
-                              QWidget *parent = 0);
+                              QWidget *parent = nullptr);
 
     /**
      * Destructor. Deletes all resources used by a KShortcutsDialog object.
      */
-    virtual ~KShortcutsDialog();
+    ~KShortcutsDialog() override;
 
     /**
      * Add all actions of the collection to the ones displayed and configured
@@ -102,12 +91,12 @@ public:
 
     /**
      * Run the dialog and call writeSettings() on the action collections
-     * that were added if @p bSaveSettings is true.
+     * that were added if @p saveSettings is true.
      */
     bool configure(bool saveSettings = true);
 
     /** @see QWidget::sizeHint() */
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
 
     /**
      * Pops up a modal dialog for configuring key settings. The new
@@ -123,7 +112,7 @@ public:
      * @return Accept if the dialog was closed with OK, Reject otherwise.
      */
     static int configure(KActionCollection *collection, KShortcutsEditor::LetterShortcuts allowLetterShortcuts =
-                             KShortcutsEditor::LetterShortcutsAllowed, QWidget *parent = 0, bool bSaveSettings = true);
+                             KShortcutsEditor::LetterShortcutsAllowed, QWidget *parent = nullptr, bool bSaveSettings = true);
 
     /**
      * Imports a shortcuts set up from @p path
@@ -143,7 +132,7 @@ public Q_SLOTS:
     /**
      * @reimp
      */
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
 Q_SIGNALS:
     /**
@@ -153,7 +142,6 @@ Q_SIGNALS:
 
 private:
     Q_PRIVATE_SLOT(d, void changeShortcutScheme(const QString &))
-    Q_PRIVATE_SLOT(d, void undoChanges())
     Q_PRIVATE_SLOT(d, void toggleDetails())
 
     class KShortcutsDialogPrivate;
