@@ -1,22 +1,10 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2006,2007 Andreas Hartmetz (ahartmetz@gmail.com)
-    Copyright (C) 2008 Michael Jansen <kde@michael-jansen.biz>
-    Copyright (C) 2008 Alexander Dymo <adymo@kdevelop.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006, 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2008 Michael Jansen <kde@michael-jansen.biz>
+    SPDX-FileCopyrightText: 2008 Alexander Dymo <adymo@kdevelop.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KSHORTCUTSDIALOG_P_H
@@ -25,10 +13,6 @@
 #include "kshortcutseditor.h"
 #include "kkeysequencewidget.h"
 
-#if 0
-#include <kgesture.h>
-#endif
-
 #include <kextendableitemdelegate.h>
 #include <klocalizedstring.h>
 
@@ -36,8 +20,8 @@
 #include <QMetaType>
 #include <QModelIndex>
 #include <QTreeWidget>
-#include <QtCore/QList>
-#include <QtCore/QCollator>
+#include <QList>
+#include <QCollator>
 #include <QGroupBox>
 
 class QLabel;
@@ -100,7 +84,7 @@ class KShortcutsEditorDelegate : public KExtendableItemDelegate
 public:
     KShortcutsEditorDelegate(QTreeWidget *parent, bool allowLetterShortcuts);
     //reimplemented to have some extra height
-    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
     /**
      * Set a list of action collections to check against for conflicting
@@ -108,30 +92,30 @@ public:
      *
      * @see KKeySequenceWidget::setCheckActionCollections
      */
-    void setCheckActionCollections(const QList<KActionCollection *> checkActionCollections);
+    void setCheckActionCollections(const QList<KActionCollection *> &checkActionCollections);
 
 Q_SIGNALS:
-    void shortcutChanged(QVariant, const QModelIndex &);
+    void shortcutChanged(const QVariant &, const QModelIndex &);
 public Q_SLOTS:
     void hiddenBySearchLine(QTreeWidgetItem *, bool);
 protected:
-    bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *, QEvent *) override;
 private:
     mutable QPersistentModelIndex m_editingIndex;
-    bool m_allowLetterShortcuts;
-    QWidget *m_editor;
+    const bool m_allowLetterShortcuts;
+    QWidget *m_editor = nullptr;
 
     //! List of actionCollections to check for conflicts.
     QList<KActionCollection *> m_checkActionCollections;
 
 private Q_SLOTS:
-    void itemActivated(QModelIndex index);
+    void itemActivated(const QModelIndex &index);
 
     /**
      * When the user collapses a hole subtree of shortcuts then remove eventually
      * extended items. Else we get that artefact bug. See above.
      */
-    void itemCollapsed(QModelIndex index);
+    void itemCollapsed(const QModelIndex &index);
 
     /**
      * If the user allowed stealing a shortcut we want to be able to undo
@@ -157,10 +141,10 @@ class TabConnectedWidget : public QWidget
 {
     Q_OBJECT
 public:
-    TabConnectedWidget(QWidget *parent)
+    explicit TabConnectedWidget(QWidget *parent)
         : QWidget(parent) {}
 protected:
-    void paintEvent(QPaintEvent *pe) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent *pe) override;
 };
 
 /**
@@ -176,7 +160,7 @@ public:
                        bool allowLetterShortcuts);
 
     //! @see KKeySequenceWidget::setCheckActionCollections()
-    void setCheckActionCollections(const QList<KActionCollection *> checkActionCollections);
+    void setCheckActionCollections(const QList<KActionCollection *> &checkActionCollections);
 
     //@{
     //! @see KKeySequenceWidget::checkAgainstStandardShortcuts()
@@ -221,6 +205,7 @@ private:
     KKeySequenceWidget *m_customEditor;
     bool m_isUpdating;
     QObject *m_action;
+    const QString m_noneText; // Translated "None" text for labels
 };
 
 #if 0
@@ -232,7 +217,7 @@ class KShortcutSchemesEditor: public QGroupBox
 {
     Q_OBJECT
 public:
-    KShortcutSchemesEditor(KShortcutsDialog *parent);
+    explicit KShortcutSchemesEditor(KShortcutsDialog *parent);
 
     /** @return the currently selected scheme in the editor (may differ from current app's scheme.*/
     QString currentScheme();
@@ -292,8 +277,8 @@ public:
     //! Commit the changes.
     void commit();
 
-    QVariant data(int column, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
-    bool operator<(const QTreeWidgetItem &other) const Q_DECL_OVERRIDE;
+    QVariant data(int column, int role = Qt::DisplayRole) const override;
+    bool operator<(const QTreeWidgetItem &other) const override;
 
     QKeySequence keySequence(uint column) const;
     void setKeySequence(uint column, const QKeySequence &seq);
@@ -324,8 +309,8 @@ private:
 
     //@{
     //! The original shortcuts before user changes. 0 means no change.
-    QList<QKeySequence> *m_oldLocalShortcut;
-    QList<QKeySequence> *m_oldGlobalShortcut;
+    QList<QKeySequence> *m_oldLocalShortcut = nullptr;
+    QList<QKeySequence> *m_oldGlobalShortcut = nullptr;
 #if 0
     KShapeGesture *m_oldShapeGesture;
     KRockerGesture *m_oldRockerGesture;
@@ -370,8 +355,7 @@ public:
 class KShortcutsEditorPrivate
 {
 public:
-
-    KShortcutsEditorPrivate(KShortcutsEditor *q);
+    explicit KShortcutsEditorPrivate(KShortcutsEditor *q);
 
     void initGUI(KShortcutsEditor::ActionTypes actionTypes, KShortcutsEditor::LetterShortcuts allowLetterShortcuts);
     void appendToView(uint nList, const QString &title = QString());
