@@ -1,26 +1,15 @@
-/* This file is part of the KDE libraries Copyright (C) 1998 Mark Donohoe <donohoe@kde.org>
-    Copyright (C) 1997 Nicolas Hadacek <hadacek@kde.org>
-    Copyright (C) 1998 Matthias Ettrich <ettrich@kde.org>
-    Copyright (C) 2001 Ellis Whitehead <ellis@kde.org>
-    Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
-    Copyright (C) 2007 Roberto Raggi <roberto@kdevelop.org>
-    Copyright (C) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
-    Copyright (C) 2008 Michael Jansen <kde@michael-jansen.biz>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1998 Mark Donohoe <donohoe@kde.org>
+    SPDX-FileCopyrightText: 1997 Nicolas Hadacek <hadacek@kde.org>
+    SPDX-FileCopyrightText: 1998 Matthias Ettrich <ettrich@kde.org>
+    SPDX-FileCopyrightText: 2001 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007 Roberto Raggi <roberto@kdevelop.org>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2008 Michael Jansen <kde@michael-jansen.biz>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "config-xmlgui.h"
 
@@ -30,10 +19,6 @@
 #include <QAction>
 #include <QTreeWidgetItem>
 
-#if 0
-#include <kgesturemap.h>
-#endif
-
 #if HAVE_GLOBALACCEL
 # include <kglobalaccel.h>
 #endif
@@ -44,10 +29,6 @@ KShortcutsEditorItem::KShortcutsEditorItem(QTreeWidgetItem *parent, QAction *act
     , m_isNameBold(false)
     , m_oldLocalShortcut(nullptr)
     , m_oldGlobalShortcut(nullptr)
-#if 0
-    , m_oldShapeGesture(0)
-    , m_oldRockerGesture(0)
-#endif
 {
     // Filtering message requested by translators (scripting).
     m_id = m_action->objectName();
@@ -65,19 +46,11 @@ KShortcutsEditorItem::~KShortcutsEditorItem()
 {
     delete m_oldLocalShortcut;
     delete m_oldGlobalShortcut;
-#if 0
-    delete m_oldShapeGesture;
-    delete m_oldRockerGesture;
-#endif
 }
 
 bool KShortcutsEditorItem::isModified() const
 {
-#if 0
-    return m_oldLocalShortcut || m_oldGlobalShortcut || m_oldShapeGesture || m_oldRockerGesture;
-#else
     return m_oldLocalShortcut || m_oldGlobalShortcut;
-#endif
 }
 
 QVariant KShortcutsEditorItem::data(int column, int role) const
@@ -94,12 +67,6 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
         case GlobalPrimary:
         case GlobalAlternate:
             return keySequence(column);
-#if 0
-        case ShapeGesture:
-            return KGestureMap::self()->shapeGesture(m_action).shapeName();
-        case RockerGesture:
-            return KGestureMap::self()->rockerGesture(m_action).rockerName();
-#endif
         default:
             break;
         }
@@ -150,18 +117,6 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
         case GlobalPrimary:
         case GlobalAlternate:
             return keySequence(column);
-#if 0
-        case ShapeGesture: { //scoping for "ret"
-            QVariant ret;
-            ret.setValue(KGestureMap::self()->shapeGesture(m_action));
-            return ret;
-        }
-        case RockerGesture: {
-            QVariant ret;
-            ret.setValue(KGestureMap::self()->rockerGesture(m_action));
-            return ret;
-        }
-#endif
         default:
             // Column not valid for this role
             Q_ASSERT(false);
@@ -184,18 +139,6 @@ QVariant KShortcutsEditorItem::data(int column, int role) const
             return primarySequence(defaultGlobalShortcuts);
         case GlobalAlternate:
             return alternateSequence(defaultGlobalShortcuts);
-#endif
-#if 0
-        case ShapeGesture: {
-            QVariant ret;
-            ret.setValue(KGestureMap::self()->defaultShapeGesture(m_action));
-            return ret;
-        }
-        case RockerGesture: {
-            QVariant ret;
-            ret.setValue(KGestureMap::self()->defaultRockerGesture(m_action));
-            return ret;
-        }
 #endif
         default:
             // Column not valid for this role
@@ -221,21 +164,22 @@ bool KShortcutsEditorItem::operator<(const QTreeWidgetItem &other) const
 
 QKeySequence KShortcutsEditorItem::keySequence(uint column) const
 {
-    QList<QKeySequence> shortcuts = m_action->shortcuts();
+    auto shortcuts = [this]() { return m_action->shortcuts(); };
+
 #if HAVE_GLOBALACCEL
-    QList<QKeySequence> globalShortcuts = KGlobalAccel::self()->shortcut(m_action);
+    auto globalShortcuts = [this]() { return KGlobalAccel::self()->shortcut(m_action); };
 #endif
 
     switch (column) {
     case LocalPrimary:
-        return primarySequence(shortcuts);
+        return primarySequence(shortcuts());
     case LocalAlternate:
-        return alternateSequence(shortcuts);
+        return alternateSequence(shortcuts());
 #if HAVE_GLOBALACCEL
     case GlobalPrimary:
-        return primarySequence(globalShortcuts);
+        return primarySequence(globalShortcuts());
     case GlobalAlternate:
-        return alternateSequence(globalShortcuts);
+        return alternateSequence(globalShortcuts());
 #endif
     default:
         return QKeySequence();
@@ -292,30 +236,6 @@ void KShortcutsEditorItem::setKeySequence(uint column, const QKeySequence &seq)
     updateModified();
 }
 
-#if 0
-void KShortcutsEditorItem::setShapeGesture(const KShapeGesture &gst)
-{
-    if (!m_oldShapeGesture) {
-        m_oldShapeGesture = new KShapeGesture(gst);
-    }
-    KGestureMap::self()->setShapeGesture(m_action, gst);
-    KGestureMap::self()->setDefaultShapeGesture(m_action, gst);
-    updateModified();
-}
-#endif
-
-#if 0
-void KShortcutsEditorItem::setRockerGesture(const KRockerGesture &gst)
-{
-    if (!m_oldRockerGesture) {
-        m_oldRockerGesture = new KRockerGesture(gst);
-    }
-    KGestureMap::self()->setRockerGesture(m_action, gst);
-    KGestureMap::self()->setDefaultRockerGesture(m_action, gst);
-    updateModified();
-}
-#endif
-
 //our definition of modified is "modified since the chooser was shown".
 void KShortcutsEditorItem::updateModified()
 {
@@ -329,16 +249,6 @@ void KShortcutsEditorItem::updateModified()
         m_oldGlobalShortcut = nullptr;
     }
 #endif
-#if 0
-    if (m_oldShapeGesture && *m_oldShapeGesture == KGestureMap::self()->shapeGesture(m_action)) {
-        delete m_oldShapeGesture;
-        m_oldShapeGesture = 0;
-    }
-    if (m_oldRockerGesture && *m_oldRockerGesture == KGestureMap::self()->rockerGesture(m_action)) {
-        delete m_oldRockerGesture;
-        m_oldRockerGesture = 0;
-    }
-#endif
 }
 
 bool KShortcutsEditorItem::isModified(uint column) const
@@ -367,12 +277,6 @@ bool KShortcutsEditorItem::isModified(uint column) const
         } else {
             return alternateSequence(*m_oldGlobalShortcut) != alternateSequence(KGlobalAccel::self()->shortcut(m_action));
         }
-#endif
-#if 0
-    case ShapeGesture:
-        return static_cast<bool>(m_oldShapeGesture);
-    case RockerGesture:
-        return static_cast<bool>(m_oldRockerGesture);
 #endif
     default:
         return false;
@@ -381,13 +285,6 @@ bool KShortcutsEditorItem::isModified(uint column) const
 
 void KShortcutsEditorItem::undo()
 {
-#ifndef NDEBUG
-#if 0
-    if (m_oldLocalShortcut || m_oldGlobalShortcut || m_oldShapeGesture || m_oldRockerGesture) {
-        //qCDebug(DEBUG_KXMLGUI) << "Undoing changes for " << data(Name, Qt::DisplayRole).toString();
-    }
-#endif
-#endif
     if (m_oldLocalShortcut) {
         // We only ever reset the active Shortcut
         m_action->setShortcuts(*m_oldLocalShortcut);
@@ -399,39 +296,13 @@ void KShortcutsEditorItem::undo()
     }
 #endif
 
-#if 0
-    if (m_oldShapeGesture) {
-        KGestureMap::self()->setShapeGesture(m_action, *m_oldShapeGesture);
-        KGestureMap::self()->setDefaultShapeGesture(m_action, *m_oldShapeGesture);
-    }
-
-    if (m_oldRockerGesture) {
-        KGestureMap::self()->setRockerGesture(m_action, *m_oldRockerGesture);
-        KGestureMap::self()->setDefaultRockerGesture(m_action, *m_oldRockerGesture);
-    }
-#endif
-
     updateModified();
 }
 
 void KShortcutsEditorItem::commit()
 {
-#ifndef NDEBUG
-#if 0
-    if (m_oldLocalShortcut || m_oldGlobalShortcut || m_oldShapeGesture || m_oldRockerGesture) {
-        //qCDebug(DEBUG_KXMLGUI) << "Committing changes for " << data(Name, Qt::DisplayRole).toString();
-    }
-#endif
-#endif
-
     delete m_oldLocalShortcut;
     m_oldLocalShortcut = nullptr;
     delete m_oldGlobalShortcut;
     m_oldGlobalShortcut = nullptr;
-#if 0
-    delete m_oldShapeGesture;
-    m_oldShapeGesture = 0;
-    delete m_oldRockerGesture;
-    m_oldRockerGesture = 0;
-#endif
 }
