@@ -1,22 +1,11 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 1999,2000 Simon Hausmann <hausmann@kde.org>
-   Copyright (C) 2000 Kurt Granroth <granroth@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 1999, 2000 Simon Hausmann <hausmann@kde.org>
+    SPDX-FileCopyrightText: 2000 Kurt Granroth <granroth@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
+
 #include "config-xmlgui.h"
 
 #include "kxmlguifactory.h"
@@ -30,14 +19,13 @@
 #include "debug.h"
 
 #include <QAction>
-#include <QtCore/QDir>
-#include <QtXml/QDomDocument>
-#include <QtCore/QFile>
-#include <QtCore/QCoreApplication>
-#include <QtCore/QTextStream>
+#include <QDir>
+#include <QDomDocument>
+#include <QFile>
+#include <QCoreApplication>
+#include <QTextStream>
 #include <QWidget>
-#include <QtCore/QDate>
-#include <QtCore/QVariant>
+#include <QVariant>
 #include <QTextCodec>
 #include <QStandardPaths>
 
@@ -120,10 +108,10 @@ QString KXMLGUIFactory::readConfigFile(const QString &filename, const QString &_
         xml_file = filename;
     } else {
         // KF >= 5.1 (KXMLGUI_INSTALL_DIR)
-        xml_file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kxmlgui5/") + componentName + QLatin1Char('/') + filename);
+        xml_file = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kxmlgui5/") + componentName + QLatin1Char('/') + filename);
         if (!QFile::exists(xml_file)) {
             // KF >= 5.4 (resource file)
-            xml_file = QStringLiteral(":/kxmlgui5/") + componentName + QLatin1Char('/') + filename;
+            xml_file = QLatin1String(":/kxmlgui5/") + componentName + QLatin1Char('/') + filename;
         }
 
         bool warn = false;
@@ -148,7 +136,7 @@ QString KXMLGUIFactory::readConfigFile(const QString &filename, const QString &_
 
     QFile file(xml_file);
     if (xml_file.isEmpty() || !file.open(QIODevice::ReadOnly)) {
-        qCritical() << "No such XML file" << filename;
+        qCCritical(DEBUG_KXMLGUI) << "No such XML file" << filename;
         return QString();
     }
 
@@ -164,13 +152,13 @@ bool KXMLGUIFactory::saveConfigFile(const QDomDocument &doc,
 
     if (QDir::isRelativePath(xml_file))
         xml_file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +
-            QStringLiteral("/kxmlgui5/") + componentName + QLatin1Char('/') + filename;
+            QLatin1String("/kxmlgui5/") + componentName + QLatin1Char('/') + filename;
 
     QFileInfo fileInfo(xml_file);
     QDir().mkpath(fileInfo.absolutePath());
     QFile file(xml_file);
     if (xml_file.isEmpty() || !file.open(QIODevice::WriteOnly)) {
-        qCritical() << "Could not write to" << filename;
+        qCCritical(DEBUG_KXMLGUI) << "Could not write to" << filename;
         return false;
     }
 
@@ -196,7 +184,7 @@ KXMLGUIFactory::KXMLGUIFactory(KXMLGUIBuilder *builder, QObject *parent)
 
 KXMLGUIFactory::~KXMLGUIFactory()
 {
-    Q_FOREACH (KXMLGUIClient *client, d->m_clients) {
+    for (KXMLGUIClient *client : qAsConst(d->m_clients)) {
         client->setFactory(nullptr);
     }
     delete d;
@@ -284,7 +272,8 @@ void KXMLGUIFactory::addClient(KXMLGUIClient *client)
     emit clientAdded(client);
 
     // build child clients
-    Q_FOREACH (KXMLGUIClient *child, client->childClients()) {
+    const auto children = client->childClients();
+    for (KXMLGUIClient *child : children) {
         addClient(child);
     }
 
@@ -307,7 +296,7 @@ void KXMLGUIFactory::addClient(KXMLGUIClient *client)
 
 void KXMLGUIFactory::refreshActionProperties()
 {
-    Q_FOREACH (KXMLGUIClient *client, d->m_clients) {
+    for (KXMLGUIClient *client : qAsConst(d->m_clients)) {
         d->guiClient = client;
         QDomDocument doc = client->xmlguiBuildDocument();
         if (doc.documentElement().isNull()) {
@@ -350,7 +339,7 @@ void KXMLGUIFactoryPrivate::refreshActionProperties(KXMLGUIClient *client, const
         applyShortcutScheme(schemeName, client, actions);
     } else {
         // apply saved default shortcuts
-        Q_FOREACH (QAction *action, actions) {
+        for (QAction *action : actions) {
             QVariant savedDefaultShortcut = action->property("_k_DefaultShortcut");
             if (savedDefaultShortcut.isValid()) {
                 QList<QKeySequence> shortcut = savedDefaultShortcut.value<QList<QKeySequence> >();
@@ -375,7 +364,7 @@ void KXMLGUIFactoryPrivate::saveDefaultActionProperties(const QList<QAction *> &
     // This method is called every time the user activated a new
     // kxmlguiclient. We only want to execute the following code only once in
     // the lifetime of an action.
-    Q_FOREACH (QAction *action, actions) {
+    for (QAction *action : actions) {
         // Skip nullptr actions or those we have seen already.
         if (!action || action->property("_k_DefaultShortcut").isValid()) {
             continue;
@@ -389,7 +378,7 @@ void KXMLGUIFactoryPrivate::saveDefaultActionProperties(const QList<QAction *> &
         // Check if we have an empty default shortcut and an non empty
         // custom shortcut. Print out a warning and correct the mistake.
         if ((!activeShortcut.isEmpty()) && defaultShortcut.isEmpty()) {
-            qCritical() << "Shortcut for action " << action->objectName() << action->text() << "set with QAction::setShortcut()! Use KActionCollection::setDefaultShortcut(s) instead.";
+            qCCritical(DEBUG_KXMLGUI) << "Shortcut for action " << action->objectName() << action->text() << "set with QAction::setShortcut()! Use KActionCollection::setDefaultShortcut(s) instead.";
             action->setProperty("_k_DefaultShortcut", QVariant::fromValue(activeShortcut));
         } else {
             action->setProperty("_k_DefaultShortcut", QVariant::fromValue(defaultShortcut));
@@ -430,7 +419,7 @@ void KXMLGUIFactory::removeClient(KXMLGUIClient *client)
     // remove child clients first (create a copy of the list just in case the
     // original list is modified directly or indirectly in removeClient())
     const QList<KXMLGUIClient *> childClients(client->childClients());
-    Q_FOREACH (KXMLGUIClient *child, childClients) {
+    for (KXMLGUIClient *child : childClients) {
         removeClient(child);
     }
 
@@ -526,7 +515,7 @@ QWidget *KXMLGUIFactoryPrivate::findRecursive(KXMLGUI::ContainerNode *node, bool
         return node->container;
     }
 
-    Q_FOREACH (ContainerNode *child, node->children) {
+    for (ContainerNode *child : qAsConst(node->children)) {
         QWidget *cont = findRecursive(child, tag);
         if (cont) {
             return cont;
@@ -555,7 +544,7 @@ QList<QWidget *> KXMLGUIFactoryPrivate::findRecursive(KXMLGUI::ContainerNode *no
         res.append(node->container);
     }
 
-    Q_FOREACH (KXMLGUI::ContainerNode *child, node->children) {
+    for (KXMLGUI::ContainerNode *child : qAsConst(node->children)) {
         res << findRecursive(child, tagName);
     }
 
@@ -655,7 +644,7 @@ void KXMLGUIFactoryPrivate::configureAction(QAction *action, const QDomAttr &att
         propertyValue = QVariant(attribute.value().toUInt());
     } else if (isShortcut) {
         // Setting the shortcut by property also sets the default shortcut (which is incorrect), so we have to do it directly
-        if (attrName == QStringLiteral("globalShortcut")) {
+        if (attrName == QLatin1String("globalShortcut")) {
 #if HAVE_GLOBALACCEL
             KGlobalAccel::self()->setShortcut(action, QKeySequence::listFromString(attribute.value()));
 #endif
@@ -676,7 +665,7 @@ void KXMLGUIFactoryPrivate::configureAction(QAction *action, const QDomAttr &att
 void KXMLGUIFactoryPrivate::applyShortcutScheme(const QString &schemeName, KXMLGUIClient *client, const QList<QAction *> &actions)
 {
     //First clear all existing shortcuts
-    Q_FOREACH (QAction *action, actions) {
+    for (QAction *action : actions) {
         action->setShortcuts(QList<QKeySequence>());
         // We clear the default shortcut as well because the shortcut scheme will set its own defaults
         action->setProperty("defaultShortcuts", QVariant::fromValue(QList<QKeySequence>()));
@@ -726,7 +715,7 @@ int KXMLGUIFactory::configureShortcuts(bool letterCutsOk, bool bSaveSettings)
     KShortcutsDialog dlg(KShortcutsEditor::AllActions,
                          letterCutsOk ? KShortcutsEditor::LetterShortcutsAllowed : KShortcutsEditor::LetterShortcutsDisallowed,
                          qobject_cast<QWidget *>(parent()));
-    Q_FOREACH (KXMLGUIClient *client, d->m_clients) {
+    for (KXMLGUIClient *client : qAsConst(d->m_clients)) {
         if (client) {
             qCDebug(DEBUG_KXMLGUI) << "Adding collection from client" << client->componentName() << "with" << client->actionCollection()->count() << "actions";
             dlg.addCollection(client->actionCollection());
