@@ -1,16 +1,16 @@
+#include "kwindowtest.h"
+
 #include <QMessageBox>
 #include <QTextEdit>
-#include <QtCore/QDir>
+#include <QDir>
 #include <QTest>
 
 #include <stdlib.h>
 
 #include <QAction>
 #include <QApplication>
-#include <QStatusBar>
 #include <QComboBox>
 #include <khelpmenu.h>
-#include "kwindowtest.h"
 #include <QLineEdit>
 #include <kxmlguifactory.h>
 #include <kactionmenu.h>
@@ -46,7 +46,6 @@ TestWindow::TestWindow(QWidget *parent)
     KActionMenu *fileFloppyAction = new KActionMenu(QIcon::fromTheme(QStringLiteral("filefloppy")),
             QStringLiteral("Save (beep or delayed popup)"), this);
     actionCollection()->addAction(QStringLiteral("filefloppy"), fileFloppyAction);
-    fileFloppyAction->setDelayed(true);
     connect(fileFloppyAction, SIGNAL(triggered(bool)), SLOT(slotSave()));
 
     QAction *filePrintAction = new QAction(QIcon::fromTheme(QStringLiteral("document-print")),
